package com.ruoyi.brewery.mapper;

import java.util.List;
import com.ruoyi.brewery.domain.WyBreweryShareLog;

/**
 * 品牌方分享方案参与记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-02-23
 */
public interface WyBreweryShareLogMapper 
{
    /**
     * 查询品牌方分享方案参与记录
     * 
     * @param id 品牌方分享方案参与记录主键
     * @return 品牌方分享方案参与记录
     */
    public WyBreweryShareLog selectWyBreweryShareLogById(Long id);

    /**
     * 查询品牌方分享方案参与记录列表
     * 
     * @param wyBreweryShareLog 品牌方分享方案参与记录
     * @return 品牌方分享方案参与记录集合
     */
    public List<WyBreweryShareLog> selectWyBreweryShareLogList(WyBreweryShareLog wyBreweryShareLog);

    /**
     * 新增品牌方分享方案参与记录
     * 
     * @param wyBreweryShareLog 品牌方分享方案参与记录
     * @return 结果
     */
    public int insertWyBreweryShareLog(WyBreweryShareLog wyBreweryShareLog);

    /**
     * 修改品牌方分享方案参与记录
     * 
     * @param wyBreweryShareLog 品牌方分享方案参与记录
     * @return 结果
     */
    public int updateWyBreweryShareLog(WyBreweryShareLog wyBreweryShareLog);

    /**
     * 删除品牌方分享方案参与记录
     * 
     * @param id 品牌方分享方案参与记录主键
     * @return 结果
     */
    public int deleteWyBreweryShareLogById(Long id);

    /**
     * 批量删除品牌方分享方案参与记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBreweryShareLogByIds(Long[] ids);
}
